# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import


from ._models import (  # type: ignore
    ApplicableMacc,
    AppliedScopeProperties,
    AutomaticShortfallSuppressReason,
    Award,
    BenefitValidateModel,
    BenefitValidateRequest,
    BenefitValidateResponse,
    BenefitValidateResponseProperty,
    BillingPlanInformation,
    CatalogClaimsItem,
    ChargeShortfallRequest,
    Commitment,
    ConditionalCredit,
    ConditionalCreditContributor,
    ConditionalCreditMilestone,
    ConditionalCreditMilestoneBase,
    ConditionalCreditPatchRequest,
    ConditionalCreditPatchRequestProperties,
    ConditionalCreditProperties,
    ConditionalCreditsValidateModel,
    ConditionsItem,
    Contributor,
    ContributorConditionalCreditMilestone,
    ContributorConditionalCreditProperties,
    Credit,
    CreditBreakdownItem,
    CreditDimension,
    CreditPatchProperties,
    CreditPatchRequest,
    CreditPolicies,
    CreditProperties,
    CreditReason,
    CreditSource,
    CreditSourcePatchRequest,
    CreditSourceProperties,
    CreditsValidateModel,
    CustomPriceProperties,
    Discount,
    DiscountPatchRequest,
    DiscountPatchRequestProperties,
    DiscountProperties,
    DiscountTypeCustomPrice,
    DiscountTypeCustomPriceMultiCurrency,
    DiscountTypeProduct,
    DiscountTypeProductFamily,
    DiscountTypeProductSku,
    DiscountTypeProperties,
    EntityTypeAffiliateDiscount,
    EntityTypePrimaryDiscount,
    ErrorAdditionalInfo,
    ErrorDetail,
    ErrorResponse,
    ExtendedStatusInfo,
    FreeServices,
    FreeServicesPatchRequest,
    FreeServicesPatchRequestProperties,
    FreeServicesProperties,
    Macc,
    MaccMilestone,
    MaccModelProperties,
    MaccPatchRequest,
    MaccPatchRequestProperties,
    MaccValidateModel,
    ManagedServiceIdentity,
    MarketSetPricesItems,
    Operation,
    OperationDisplay,
    PaymentDetail,
    Plan,
    Price,
    PriceGuaranteeProperties,
    PrimaryConditionalCreditProperties,
    ProxyResource,
    PurchaseRequest,
    PurchaseRequestProperties,
    RenewProperties,
    ReservationOrderAliasRequest,
    ReservationOrderAliasRequestProperties,
    ReservationOrderAliasRequestPropertiesReservedResourceProperties,
    ReservationOrderAliasResponse,
    ReservationOrderAliasResponseProperties,
    ReservationOrderAliasResponsePropertiesReservedResourceProperties,
    Resource,
    ResourceSku,
    RoleAssignmentEntity,
    RoleAssignmentEntityProperties,
    SavingsPlanModel,
    SavingsPlanModelProperties,
    SavingsPlanOrderAliasModel,
    SavingsPlanOrderAliasProperties,
    SavingsPlanOrderModel,
    SavingsPlanOrderModelProperties,
    SavingsPlanSummary,
    SavingsPlanSummaryCount,
    SavingsPlanUpdateRequest,
    SavingsPlanUpdateRequestProperties,
    SavingsPlanUpdateValidateRequest,
    SavingsPlanValidResponseProperty,
    SavingsPlanValidateModel,
    SavingsPlanValidateResponse,
    SellerResourceListRequest,
    SellerResourceListRequestProperties,
    ServiceManagedIdentity,
    Shortfall,
    Sku,
    SystemData,
    TrackedResource,
    UserAssignedIdentity,
    Utilization,
    UtilizationAggregates,
)

from ._enums import (  # type: ignore
    ActionType,
    AppliedScopeType,
    ApplyDiscountOn,
    BenefitType,
    BillingPlan,
    CommitmentGrain,
    ConditionalCreditEntityType,
    ConditionalCreditStatus,
    ConditionalCreditsProvisioningState,
    CreatedByType,
    CreditExpirationPolicy,
    CreditRedemptionPolicy,
    CreditStatus,
    DiscountAppliedScopeType,
    DiscountCombinationRule,
    DiscountEntityType,
    DiscountProvisioningState,
    DiscountRuleType,
    DiscountStatus,
    DiscountType,
    EnablementMode,
    FreeServicesStatus,
    InstanceFlexibility,
    MaccEntityType,
    MaccMilestoneStatus,
    MaccStatus,
    ManagedServiceIdentityType,
    MilestoneStatus,
    Origin,
    PaymentStatus,
    PricingPolicy,
    ProvisioningState,
    ReservedResourceType,
    ServiceManagedIdentityType,
    SkuTier,
    Term,
)
from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "ApplicableMacc",
    "AppliedScopeProperties",
    "AutomaticShortfallSuppressReason",
    "Award",
    "BenefitValidateModel",
    "BenefitValidateRequest",
    "BenefitValidateResponse",
    "BenefitValidateResponseProperty",
    "BillingPlanInformation",
    "CatalogClaimsItem",
    "ChargeShortfallRequest",
    "Commitment",
    "ConditionalCredit",
    "ConditionalCreditContributor",
    "ConditionalCreditMilestone",
    "ConditionalCreditMilestoneBase",
    "ConditionalCreditPatchRequest",
    "ConditionalCreditPatchRequestProperties",
    "ConditionalCreditProperties",
    "ConditionalCreditsValidateModel",
    "ConditionsItem",
    "Contributor",
    "ContributorConditionalCreditMilestone",
    "ContributorConditionalCreditProperties",
    "Credit",
    "CreditBreakdownItem",
    "CreditDimension",
    "CreditPatchProperties",
    "CreditPatchRequest",
    "CreditPolicies",
    "CreditProperties",
    "CreditReason",
    "CreditSource",
    "CreditSourcePatchRequest",
    "CreditSourceProperties",
    "CreditsValidateModel",
    "CustomPriceProperties",
    "Discount",
    "DiscountPatchRequest",
    "DiscountPatchRequestProperties",
    "DiscountProperties",
    "DiscountTypeCustomPrice",
    "DiscountTypeCustomPriceMultiCurrency",
    "DiscountTypeProduct",
    "DiscountTypeProductFamily",
    "DiscountTypeProductSku",
    "DiscountTypeProperties",
    "EntityTypeAffiliateDiscount",
    "EntityTypePrimaryDiscount",
    "ErrorAdditionalInfo",
    "ErrorDetail",
    "ErrorResponse",
    "ExtendedStatusInfo",
    "FreeServices",
    "FreeServicesPatchRequest",
    "FreeServicesPatchRequestProperties",
    "FreeServicesProperties",
    "Macc",
    "MaccMilestone",
    "MaccModelProperties",
    "MaccPatchRequest",
    "MaccPatchRequestProperties",
    "MaccValidateModel",
    "ManagedServiceIdentity",
    "MarketSetPricesItems",
    "Operation",
    "OperationDisplay",
    "PaymentDetail",
    "Plan",
    "Price",
    "PriceGuaranteeProperties",
    "PrimaryConditionalCreditProperties",
    "ProxyResource",
    "PurchaseRequest",
    "PurchaseRequestProperties",
    "RenewProperties",
    "ReservationOrderAliasRequest",
    "ReservationOrderAliasRequestProperties",
    "ReservationOrderAliasRequestPropertiesReservedResourceProperties",
    "ReservationOrderAliasResponse",
    "ReservationOrderAliasResponseProperties",
    "ReservationOrderAliasResponsePropertiesReservedResourceProperties",
    "Resource",
    "ResourceSku",
    "RoleAssignmentEntity",
    "RoleAssignmentEntityProperties",
    "SavingsPlanModel",
    "SavingsPlanModelProperties",
    "SavingsPlanOrderAliasModel",
    "SavingsPlanOrderAliasProperties",
    "SavingsPlanOrderModel",
    "SavingsPlanOrderModelProperties",
    "SavingsPlanSummary",
    "SavingsPlanSummaryCount",
    "SavingsPlanUpdateRequest",
    "SavingsPlanUpdateRequestProperties",
    "SavingsPlanUpdateValidateRequest",
    "SavingsPlanValidResponseProperty",
    "SavingsPlanValidateModel",
    "SavingsPlanValidateResponse",
    "SellerResourceListRequest",
    "SellerResourceListRequestProperties",
    "ServiceManagedIdentity",
    "Shortfall",
    "Sku",
    "SystemData",
    "TrackedResource",
    "UserAssignedIdentity",
    "Utilization",
    "UtilizationAggregates",
    "ActionType",
    "AppliedScopeType",
    "ApplyDiscountOn",
    "BenefitType",
    "BillingPlan",
    "CommitmentGrain",
    "ConditionalCreditEntityType",
    "ConditionalCreditStatus",
    "ConditionalCreditsProvisioningState",
    "CreatedByType",
    "CreditExpirationPolicy",
    "CreditRedemptionPolicy",
    "CreditStatus",
    "DiscountAppliedScopeType",
    "DiscountCombinationRule",
    "DiscountEntityType",
    "DiscountProvisioningState",
    "DiscountRuleType",
    "DiscountStatus",
    "DiscountType",
    "EnablementMode",
    "FreeServicesStatus",
    "InstanceFlexibility",
    "MaccEntityType",
    "MaccMilestoneStatus",
    "MaccStatus",
    "ManagedServiceIdentityType",
    "MilestoneStatus",
    "Origin",
    "PaymentStatus",
    "PricingPolicy",
    "ProvisioningState",
    "ReservedResourceType",
    "ServiceManagedIdentityType",
    "SkuTier",
    "Term",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()
